@@ -6,9 +6,9 @@ Type annotations for codeguruprofiler service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codeguruprofiler.literals import ActionGroup
+    from mypy_boto3_codeguruprofiler.literals import ActionGroupType
 
-    data: ActionGroup = "agentPermissions"
+    data: ActionGroupType = "agentPermissions"
     ```
 """
 import sys
@@ -20,33 +20,33 @@ else:
 
 
 __all__ = (
-    "ActionGroup",
-    "AgentParameterField",
-    "AggregationPeriod",
-    "ComputePlatform",
-    "EventPublisher",
-    "FeedbackType",
+    "ActionGroupType",
+    "AgentParameterFieldType",
+    "AggregationPeriodType",
+    "ComputePlatformType",
+    "EventPublisherType",
+    "FeedbackTypeType",
     "ListProfileTimesPaginatorName",
-    "MetadataField",
-    "MetricType",
-    "OrderBy",
+    "MetadataFieldType",
+    "MetricTypeType",
+    "OrderByType",
 )
 
 
-ActionGroup = Literal["agentPermissions"]
-AgentParameterField = Literal[
+ActionGroupType = Literal["agentPermissions"]
+AgentParameterFieldType = Literal[
     "MaxStackDepth",
     "MemoryUsageLimitPercent",
     "MinimumTimeForReportingInMilliseconds",
     "ReportingIntervalInMilliseconds",
     "SamplingIntervalInMilliseconds",
 ]
-AggregationPeriod = Literal["P1D", "PT1H", "PT5M"]
-ComputePlatform = Literal["AWSLambda", "Default"]
-EventPublisher = Literal["AnomalyDetection"]
-FeedbackType = Literal["Negative", "Positive"]
+AggregationPeriodType = Literal["P1D", "PT1H", "PT5M"]
+ComputePlatformType = Literal["AWSLambda", "Default"]
+EventPublisherType = Literal["AnomalyDetection"]
+FeedbackTypeType = Literal["Negative", "Positive"]
 ListProfileTimesPaginatorName = Literal["list_profile_times"]
-MetadataField = Literal[
+MetadataFieldType = Literal[
     "AgentId",
     "AwsRequestId",
     "ComputePlatform",
@@ -57,5 +57,5 @@ MetadataField = Literal[
     "LambdaRemainingTimeInMilliseconds",
     "LambdaTimeGapBetweenInvokesInMilliseconds",
 ]
-MetricType = Literal["AggregatedRelativeTotalTime"]
-OrderBy = Literal["TimestampAscending", "TimestampDescending"]
+MetricTypeType = Literal["AggregatedRelativeTotalTime"]
+OrderByType = Literal["TimestampAscending", "TimestampDescending"]
